@@ -1,6 +1,6 @@
 """History manager extension for the standard Python shell and IPython"""
 
-__version__ = "0.4.1"
+__version__ = "0.5.0"
 
 import curses
 import sys
@@ -10,14 +10,15 @@ try:
 except ModuleNotFoundError:  # pragma: no cover
     IPython = None
 
-from pyhstr.application import SHELL, main
+from pyhstr.__main__ import main
+from pyhstr.application import SHELL
 from pyhstr.utilities import Shell
 
 hh = object()
 original = sys.displayhook
 
 
-def spam(arg):
+def spam(arg: object) -> None:
     if arg == hh:
         curses.wrapper(main)
     else:
@@ -29,7 +30,7 @@ if SHELL != Shell.IPYTHON:
 else:
 
     @IPython.core.magic.register_line_magic
-    def hh(line):  # pylint: disable=function-redefined,unused-argument
+    def hh(line: str) -> None:  # pylint: disable=function-redefined,unused-argument
         """
         This line magic mirrors the behaviour of sys.displayhook
         in the regular Python shell. Use %hh to invoke.
