@@ -1,17 +1,20 @@
 import curses
 import sys
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Union, TYPE_CHECKING
 from pyhstr.utilities import View
 
+if TYPE_CHECKING:
+    from pyhstr.application import App  # pylint: disable=cyclic-import
 
-COLORS: Dict[str, Optional[int]] = {
+
+COLORS: Dict[str, int] = {
     # yet to be initialized
-    "normal": None,
-    "highlighted-white": None,
-    "highlighted-green": None,
-    "highlighted-red": None,
-    "white": None,
-    "bold-red": None,
+    "normal": 0,
+    "highlighted-white": 0,
+    "highlighted-green": 0,
+    "highlighted-red": 0,
+    "white": 0,
+    "bold-red": 0,
 }
 
 PYHSTR_LABEL = (
@@ -39,13 +42,11 @@ DISPLAY: Dict[str, Dict[Union[View, bool], str]] = {
 
 
 class UserInterface:
-    def __init__(self, app):
+    def __init__(self, app: "App"):
         self.app = app
         self.page = Page(self.app)
 
-    def _addstr(
-        self, y_coord: int, x_coord: int, text: str, color_info: Optional[int]
-    ) -> None:
+    def _addstr(self, y_coord: int, x_coord: int, text: str, color_info: int) -> None:
         """
         Works around curses' limitation of drawing at bottom right corner
         of the screen, as seen on https://stackoverflow.com/q/36387625
@@ -136,15 +137,20 @@ class UserInterface:
         self._addstr(0, 1, PS1 + self.app.search_string, COLORS["normal"])
 
     def get_matched_chars(self, command: str) -> List[int]:
-        return [
-            cmd_idx
-            for m in self.app.create_search_regex().finditer(command)
-            for cmd_idx in range(m.start(), m.end())
-        ]
+        regex = self.app.create_search_regex()
+        return (
+            []
+            if regex is None
+            else [
+                cmd_idx
+                for m in regex.finditer(command)
+                for cmd_idx in range(m.start(), m.end())
+            ]
+        )
 
 
 class Page:
-    def __init__(self, app):
+    def __init__(self, app: "App"):
         self.value = 1
         self.app = app
         self.selected = SelectedCmd(self)
@@ -196,7 +202,7 @@ class Page:
 
 
 class SelectedCmd:  # pylint: disable=too-few-public-methods
-    def __init__(self, page):
+    def __init__(self, page: Page):
         self.value = 0
         self.page = page
 
