@@ -1,7 +1,6 @@
 import collections
 import enum
 import fcntl
-import sys
 import termios
 from pathlib import Path
 from typing import List, Optional
@@ -94,8 +93,9 @@ def is_ipython() -> bool:
         return IPython.get_ipython() is not None
     return False
 
+
 def is_bpython() -> bool:
-    return Path(sys.argv[0]).name == Shell.BPYTHON.value
+    return help.__module__.startswith("bpython")
 
 
 def detect_shell() -> Shell:
